==> symfony_5.4.4+dfsg.orig.tar.xz: symfony-5.4.4/src/Symfony/Component/Intl/Resources/data/regions/ha.php <==
<?php

return [
    'Names' => [
        'AD' => 'Andora',
        'AE' => 'Haɗaɗɗiyar Daular Larabawa',
        'AF' => 'Afaganistan',
        'AG' => 'Antigua da Barbuda',
        'AI' => 'Angila',
        'AL' => 'Albaniya',
        'AM' => 'Armeniya',
        'AO' => 'Angola',
        'AQ' => 'Antatika',
        'AR' => 'Arjantiniya',
        'AS' => 'Samowa Ta Amurka',
        'AT' => 'Ostiriya',
        'AU' => 'Ostareliya',
        'AW' => 'Aruba',
        'AX' => 'Tsibirai na Åland',
        'AZ' => 'Azarbaijan',
        'BA' => 'Bosniya da Harzagobina',
        'BB' => 'Barbadas',
        'BD' => 'Bangiladas',
        'BE' => 'Belgiyom',
        'BF' => 'Burkina Faso',
        'BG' => 'Bulgariya',
        'BH' => 'Baharan',
        'BI' => 'Burundi',
        'BJ' => 'Binin',
        'BL' => 'San Barthélemy',
        'BM' => 'Barmuda',
        'BN' => 'Burune',
        'BO' => 'Bolibiya',
        'BQ' => 'Caribbean Netherlands',
        'BR' => 'Birazil',
        'BS' => 'Bahamas',
        'BT' => 'Butan',
        'BV' => 'Tsibirin Bouvet',
        'BW' => 'Baswana',
        'BY' => 'Belarus',
        'BZ' => 'Beliz',
        'CA' => 'Kanada',
        'CC' => 'Tsibirai Cocos (Keeling)',
        'CD' => 'Jamhuriyar Dimokuraɗiyyar Kongo',
        'CF' => 'Jamhuriyar Afirka Ta Tsakiya',
        'CG' => 'Kongo',
        'CH' => 'Suwizalan',
        'CI' => 'Aibari Kwas',
        'CK' => 'Tsibiran Kuku',
        'CL' => 'Cayile',
        'CM' => 'Kamaru',
        'CN' => 'Sin',
        'CO' => 'Kolambiya',
        'CR' => 'Kwasta Rika',
        'CU' => 'Kyuba',
        'CV' => 'Tsibiran Kap Barde',
        'CW' => 'Ƙasar Curaçao',
        'CX' => 'Tsibirin Kirsmati',
        'CY' => 'Sifurus',
        'CZ' => 'Jamhuriyar Cak',
        'DE' => 'Jamus',
        'DJ' => 'Jibuti',
        'DK' => 'Danmark',
        'DM' => 'Dominika',
        'DO' => 'Jamhuriyar Dominika',
        'DZ' => 'Aljeriya',
        'EC' => 'Ekwador',
        'EE' => 'Estoniya',
        'EG' => 'Misira',
        'EH' => 'Yammacin Sahara',
        'ER' => 'Eritireya',
        'ES' => 'Sipen',
        'ET' => 'Habasha',
        'FI' => 'Finlan',
        'FJ' => 'Fiji',
        'FK' => 'Tsibiran Falkilan',
        'FM' => 'Mikuronesiya',
        'FO' => 'Tsibirai na Faroe',
        'FR' => 'Faransa',
        'GA' => 'Gabon',
        'GB' => 'Biritaniya',
        'GD' => 'Girnada',
        'GE' => 'Jiwarjiya',
        'GF' => 'Gini Ta Faransa',
        'GG' => 'Yankin Guernsey',
        'GH' => 'Gana',
        'GI' => 'Jibaraltar',
        'GL' => 'Grinlan',
        'GM' => 'Gambiya',
        'GN' => 'Gini',
        'GP' => 'Gwadaluf',
        'GQ' => 'Gini Ta Ikwaita',
        'GR' => 'Girka',
        'GS' => 'Kudancin Geogia da Kudancin Tsibirin Sandiwic',
        'GT' => 'Gwatamala',
        'GU' => 'Gwam',
        'GW' => 'Gini Bisau',
        'GY' => 'Guyana',
        'HK' => 'Babban Yankin Mulkin Hong Kong na Ƙasar Sin',
        'HM' => 'Tsibirin Heard da McDonald',
        'HN' => 'Yankin Honduras',
        'HR' => 'Kurowaishiya',
        'HT' => 'Haiti',
        'HU' => 'Hungari',
        'ID' => 'Indunusiya',
        'IE' => 'Ayalan',
        'IL' => 'Israʼila',
        'IM' => 'Isle na Mutum',
        'IN' => 'Indiya',
        'IO' => 'Yankin Birtaniya Na Tekun Indiya',
        'IQ' => 'Iraƙi',
        'IR' => 'Iran',
        'IS' => 'Aisalan',
        'IT' => 'Italiya',
        'JE' => 'Kasar Jersey',
        'JM' => 'Jamaika',
        'JO' => 'Jordan',
        'JP' => 'Japan',
        'KE' => 'Kenya',
        'KG' => 'Kirgizistan',
        'KH' => 'Kambodiya',
        'KI' => 'Kiribati',
        'KM' => 'Kwamoras',
        'KN' => 'San Kiti Da Nebis',
        'KP' => 'Koriya Ta Arewa',
        'KR' => 'Koriya Ta Kudu',
        'KW' => 'Kwiyat',
        'KY' => 'Tsibiran Kaiman',
        'KZ' => 'Kazakistan',
        'LA' => 'Lawas',
        'LB' => 'Labanan',
        'LC' => 'San Lusiya',
        'LI' => 'Licansitan',
        'LK' => 'Siri Lanka',
        'LR' => 'Laberiya',
        'LS' => 'Lesoto',
        'LT' => 'Lituweniya',
        'LU' => 'Lukusambur',
        'LV' => 'Litibiya',
        'LY' => 'Libiya',
        'MA' => 'Maroko',
        'MC' => 'Monako',
        'MD' => 'Maldoba',
        'ME' => 'Mantanegara',
        'MF' => 'San Martin',
        'MG' => 'Madagaskar',
        'MH' => 'Tsibiran Marshal',
        'MK' => 'Macedonia ta Arewa',
        'ML' => 'Mali',
        'MM' => 'Burma, Miyamar',
        'MN' => 'Mangoliya',
        'MO' => 'Babban Yankin Mulkin Macao na Ƙasar Sin',
        'MP' => 'Tsibiran Mariyana Na Arewa',
        'MQ' => 'Martinik',
        'MR' => 'Moritaniya',
        'MS' => 'Manserati',
        'MT' => 'Malta',
        'MU' => 'Moritus',
        'MV' => 'Maldibi',
        'MW' => 'Malawi',
        'MX' => 'Mesiko',
        'MY' => 'Malaisiya',
        'MZ' => 'Mozambik',
        'NA' => 'Namibiya',
        'NC' => 'Kaledoniya Sabuwa',
        'NE' => 'Nijar',
        'NF' => 'Tsibirin Narfalk',
        'NG' => 'Najeriya',
        'NI' => 'Nikaraguwa',
        'NL' => 'Holan',
        'NO' => 'Norwe',
        'NP' => 'Nefal',
        'NR' => 'Nauru',
        'NU' => 'Niyu',
        'NZ' => 'Nuzilan',
        'OM' => 'Oman',
        'PA' => 'Panama',
        'PE' => 'Feru',
        'PF' => 'Folinesiya Ta Faransa',
        'PG' => 'Papuwa Nugini',
        'PH' => 'Filipin',
        'PK' => 'Pakistan',
        'PL' => 'Polan',
        'PM' => 'San Piyar da Mikelan',
        'PN' => 'Pitakarin',
        'PR' => 'Porto Riko',
        'PS' => 'Yankunan Palasɗinu',
        'PT' => 'Portugal',
        'PW' => 'Palau',
        'PY' => 'Faragwai',
        'QA' => 'Katar',
        'RE' => 'Rawuniyan',
        'RO' => 'Romaniya',
        'RS' => 'Sabiya',
        'RU' => 'Rasha',
        'RW' => 'Ruwanda',
        'SA' => 'Saudiyya',
        'SB' => 'Tsibiran Salaman',
        'SC' => 'Seychelles',
        'SD' => 'Sudan',
        'SE' => 'Suwedan',
        'SG' => 'Singapur',
        'SH' => 'San Helena',
        'SI' => 'Sulobeniya',
        'SJ' => 'Svalbard da Jan Mayen',
        'SK' => 'Sulobakiya',
        'SL' => 'Salewo',
        'SM' => 'San Marino',
        'SN' => 'Sanigal',
        'SO' => 'Somaliya',
        'SR' => 'Suriname',
        'SS' => 'Sudan ta Kudu',
        'ST' => 'Sawo Tome Da Paransip',
        'SV' => 'El Salbador',
        'SX' => 'San Maarten',
        'SY' => 'Sham, Siriya',
        'SZ' => 'Eswatini',
        'TC' => 'Turkis Da Tsibiran Kaikwas',
        'TD' => 'Cadi',
        'TF' => 'Yankin Faransi ta Kudu',
        'TG' => 'Togo',
        'TH' => 'Tailan',
        'TJ' => 'Tajikistan',
        'TK' => 'Takelau',
        'TL' => 'Timor Ta Gabas',
        'TM' => 'Turkumenistan',
        'TN' => 'Tunisiya',
        'TO' => 'Tonga',
        'TR' => 'Turkiyya',
        'TT' => 'Tirinidad Da Tobago',
        'TV' => 'Tubalu',
        'TW' => 'Taiwan',
        'TZ' => 'Tanzaniya',
        'UA' => 'Yukaran',
        'UG' => 'Yuganda',
        'UM' => 'Rukunin Tsibirin U.S',
        'US' => 'Amurka',
        'UY' => 'Yurigwai',
        'UZ' => 'Uzubekistan',
        'VA' => 'Batikan',
        'VC' => 'San Binsan Da Girnadin',
        'VE' => 'Benezuwela',
        'VG' => 'Tsibirin Birjin Na Birtaniya',
        'VI' => 'Tsibiran Birjin Ta Amurka',
        'VN' => 'Biyetinam',
        'VU' => 'Banuwatu',
        'WF' => 'Walis Da Futuna',
        'WS' => 'Samoa',
        'YE' => 'Yamal',
        'YT' => 'Mayoti',
        'ZA' => 'Afirka Ta Kudu',
        'ZM' => 'Zambiya',
        'ZW' => 'Zimbabuwe',
    ],
];

==> symfony_6.4.18+dfsg.orig.tar.xz: symfony-6.4.18/src/Symfony/Component/Intl/Resources/data/regions/ha.php <==
<?php

return [
    'Names' => [
        'AD' => 'Andora',
        'AE' => 'Haɗaɗɗiyar Daular Larabawa',
        'AF' => 'Afaganistan',
        'AG' => 'Antigua da Barbuda',
        'AI' => 'Angila',
        'AL' => 'Albaniya',
        'AM' => 'Armeniya',
        'AO' => 'Angola',
        'AQ' => 'Antatika',
        'AR' => 'Ajentina',
        'AS' => 'Samowa Ta Amurka',
        'AT' => 'Ostiriya',
        'AU' => 'Ostareliya',
        'AW' => 'Aruba',
        'AX' => 'Tsibirai na Åland',
        'AZ' => 'Azarbaijan',
        'BA' => 'Bosniya da Harzagobina',
        'BB' => 'Barbadas',
        'BD' => 'Bangladesh',
        'BE' => 'Belgiyom',
        'BF' => 'Burkina Faso',
        'BG' => 'Bulgariya',
        'BH' => 'Baharen',
        'BI' => 'Burundi',
        'BJ' => 'Binin',
        'BL' => 'San Barthélemy',
        'BM' => 'Barmuda',
        'BN' => 'Burune',
        'BO' => 'Bolibiya',
        'BQ' => 'Caribbean Netherlands',
        'BR' => 'Birazil',
        'BS' => 'Bahamas',
        'BT' => 'Butan',
        'BV' => 'Tsibirin Bouvet',
        'BW' => 'Baswana',
        'BY' => 'Belarus',
        'BZ' => 'Beliz',
        'CA' => 'Kanada',
        'CC' => 'Tsibirai Cocos (Keeling)',
        'CD' => 'Jamhuriyar Dimokuraɗiyyar Kongo',
        'CF' => 'Jamhuriyar Afirka Ta Tsakiya',
        'CG' => 'Kongo',
        'CH' => 'Suwizalan',
        'CI' => 'Aibari Kwas',
        'CK' => 'Tsibiran Cook',
        'CL' => 'Chile',
        'CM' => 'Kamaru',
        'CN' => 'Sin',
        'CO' => 'Kolambiya',
        'CR' => 'Kwasta Rika',
        'CU' => 'Kyuba',
        'CV' => 'Tsibiran Cape Verde',
        'CW' => 'Ƙasar Curaçao',
        'CX' => 'Tsibirin Kirsmati',
        'CY' => 'Saifurus',
        'CZ' => 'Czechia',
        'DE' => 'Jamus',
        'DJ' => 'Jibuti',
        'DK' => 'Danmark',
        'DM' => 'Dominika',
        'DO' => 'Jamhuriyar Dominika',
        'DZ' => 'Aljeriya',
        'EC' => 'Ekwador',
        'EE' => 'Estoniya',
        'EG' => 'Misira',
        'EH' => 'Yammacin Sahara',
        'ER' => 'Eritireya',
        'ES' => 'Sipen',
        'ET' => 'Habasha',
        'FI' => 'Finlan',
        'FJ' => 'Fiji',
        'FK' => 'Tsibiran Falkilan',
        'FM' => 'Mikuronesiya',
        'FO' => 'Tsibirai na Faroe',
        'FR' => 'Faransa',
        'GA' => 'Gabon',
        'GB' => 'Biritaniya',
        'GD' => 'Girnada',
        'GE' => 'Jojiya',
        'GF' => 'Gini Ta Faransa',
        'GG' => 'Yankin Guernsey',
        'GH' => 'Gana',
        'GI' => 'Jibaraltar',
        'GL' => 'Grinlan',
        'GM' => 'Gambiya',
        'GN' => 'Gini',
        'GP' => 'Gwadaluf',
        'GQ' => 'Ikwatoriyal Gini',
        'GR' => 'Girka',
        'GS' => 'Kudancin Geogia da Kudancin Tsibirin Sandiwic',
        'GT' => 'Gwatamala',
        'GU' => 'Guam',
        'GW' => 'Gini Bisau',
        'GY' => 'Guyana',
        'HK' => 'Babban Yankin Mulkin Hong Kong na Ƙasar Sin',
        'HM' => 'Tsibirin Heard da McDonald',
        'HN' => 'Yankin Honduras',
        'HR' => 'Kurowaishiya',
        'HT' => 'Haiti',
        'HU' => 'Hungari',
        'ID' => 'Indunusiya',
        'IE' => 'Ayalan',
        'IL' => 'Israʼila',
        'IM' => 'Isle of Man',
        'IN' => 'Indiya',
        'IO' => 'Yankin Birtaniya Na Tekun Indiya',
        'IQ' => 'Iraƙi',
        'IR' => 'Iran',
        'IS' => 'Aisalan',
        'IT' => 'Italiya',
        'JE' => 'Kasar Jersey',
        'JM' => 'Jamaika',
        'JO' => 'Jordan',
        'JP' => 'Japan',
        'KE' => 'Kenya',
        'KG' => 'Kirgizistan',
        'KH' => 'Kambodiya',
        'KI' => 'Kiribati',
        'KM' => 'Kwamoras',
        'KN' => 'San Kiti Da Nebis',
        'KP' => 'Koriya Ta Arewa',
        'KR' => 'Koriya Ta Kudu',
        'KW' => 'Kuwet',
        'KY' => 'Tsibiran Kaiman',
        'KZ' => 'Kazakistan',
        'LA' => 'Lawos',
        'LB' => 'Labanan',
        'LC' => 'San Lusiya',
        'LI' => 'Licansitan',
        'LK' => 'Siri Lanka',
        'LR' => 'Laberiya',
        'LS' => 'Lesoto',
        'LT' => 'Lituweniya',
        'LU' => 'Lukusambur',
        'LV' => 'Litibiya',
        'LY' => 'Libiya',
        'MA' => 'Maroko',
        'MC' => 'Monako',
        'MD' => 'Maldoba',
        'ME' => 'Manteneguro',
        'MF' => 'San Martin',
        'MG' => 'Madagaskar',
        'MH' => 'Tsibiran Marshal',
        'MK' => 'Macedonia ta Arewa',
        'ML' => 'Mali',
        'MM' => 'Burma, Miyamar',
        'MN' => 'Mangoliya',
        'MO' => 'Babban Yankin Mulkin Macao na Ƙasar Sin',
        'MP' => 'Tsibiran Mariyana Na Arewa',
        'MQ' => 'Martinik',
        'MR' => 'Moritaniya',
        'MS' => 'Manserati',
        'MT' => 'Malta',
        'MU' => 'Moritus',
        'MV' => 'Maldibi',
        'MW' => 'Malawi',
        'MX' => 'Mesiko',
        'MY' => 'Malesiya',
        'MZ' => 'Mozambik',
        'NA' => 'Namibiya',
        'NC' => 'Kaledoniya Sabuwa',
        'NE' => 'Nijar',
        'NF' => 'Tsibirin Narfalk',
        'NG' => 'Nijeriya',
        'NI' => 'Nikaraguwa',
        'NL' => 'Holan',
        'NO' => 'Norwe',
        'NP' => 'Nefal',
        'NR' => 'Nauru',
        'NU' => 'Niue',
        'NZ' => 'Nuzilan',
        'OM' => 'Oman',
        'PA' => 'Panama',
        'PE' => 'Feru',
        'PF' => 'Folinesiya Ta Faransa',
        'PG' => 'Papuwa Nugini',
        'PH' => 'Filipin',
        'PK' => 'Pakistan',
        'PL' => 'Polan',
        'PM' => 'San Piyar da Mikelan',
        'PN' => 'Tsibiran Pitcairn',
        'PR' => 'Porto Riko',
        'PS' => 'Yankunan Palasɗinu',
        'PT' => 'Portugal',
        'PW' => 'Palau',
        'PY' => 'Faragwai',
        'QA' => 'Katar',
        'RE' => 'Rawuniyan',
        'RO' => 'Romaniya',
        'RS' => 'Sabiya',
        'RU' => 'Rasha',
        'RW' => 'Ruwanda',
        'SA' => 'Saudiyya',
        'SB' => 'Tsibiran Salaman',
        'SC' => 'Seychelles',
        'SD' => 'Sudan',
        'SE' => 'Suwedan',
        'SG' => 'Singapur',
        'SH' => 'San Helena',
        'SI' => 'Sulobeniya',
        'SJ' => 'Svalbard da Jan Mayen',
        'SK' => 'Sulobakiya',
        'SL' => 'Salewo',
        'SM' => 'San Marino',
        'SN' => 'Sanigal',
        'SO' => 'Somaliya',
        'SR' => 'Suriname',
        'SS' => 'Sudan ta Kudu',
        'ST' => 'Sawo Tome Da Paransip',
        'SV' => 'El Salbador',
        'SX' => 'San Maarten',
        'SY' => 'Sham, Siriya',
        'SZ' => 'Eswatini',
        'TC' => 'Turkis Da Tsibiran Kaikwas',
        'TD' => 'Cadi',
        'TF' => 'Yankin Faransi ta Kudu',
        'TG' => 'Togo',
        'TH' => 'Tailan',
        'TJ' => 'Tajikistan',
        'TK' => 'Takelau',
        'TL' => 'Timor-Leste',
        'TM' => 'Turkumenistan',
        'TN' => 'Tunisiya',
        'TO' => 'Tonga',
        'TR' => 'Turkiyya',
        'TT' => 'Tirinidad Da Tobago',
        'TV' => 'Tubalu',
        'TW' => 'Taiwan',
        'TZ' => 'Tanzaniya',
        'UA' => 'Yukaran',
        'UG' => 'Yuganda',
        'UM' => 'Rukunin Tsibirin U.S',
        'US' => 'Amurka',
        'UY' => 'Yurigwai',
        'UZ' => 'Uzubekistan',
        'VA' => 'Birnin Batikan',
        'VC' => 'San Binsan Da Girnadin',
        'VE' => 'Benezuwela',
        'VG' => 'Tsibirin Birjin Na Birtaniya',
        'VI' => 'Tsibiran Birjin Ta Amurka',
        'VN' => 'Biyetinam',
        'VU' => 'Banuwatu',
        'WF' => 'Walis Da Futuna',
        'WS' => 'Samoa',
        'YE' => 'Yamen',
        'YT' => 'Mayoti',
        'ZA' => 'Afirka Ta Kudu',
        'ZM' => 'Zambiya',
        'ZW' => 'Zimbabuwe',
    ],
];
